Exec { timeout => 300 }

$amqp = 'qpid'
case $amqp  {
  'qpid': {
    enable_qpid {"qpid":
      enable_ssl  => false,
      enable_auth => 'n',
    }
  }
  'rabbitmq': {
    enable_rabbitmq {"rabbitmq":}

  }
}


define enable_rabbitmq {
  package { "erlang":
    ensure => "installed"
  }

  class {"rabbitmq":
    port             => '5672',
    ssl_management_port      => '5671',
    ssl              => false,
    ssl_cert         => '',
    ssl_key          => '',
    default_user     => 'guest',
    default_pass     => 'guest',
    package_provider => 'yum',
    admin_enable     => false,
  }

  Package['erlang']->Class['rabbitmq']
}

define enable_qpid($enable_ssl = 'n', $enable_auth = 'n') {
  case $::operatingsystem {
    'Fedora': {
      if (is_integer($::operatingsystemrelease) and $::operatingsystemrelease >= 20) or $::operatingsystemrelease == "Rawhide" {
        $config = '/etc/qpid/qpidd.conf'
      } else {
        $config = '/etc/qpidd.conf'
      }
    }

    'RedHat': {
      if $::operatingsystemmajrelease >= 7 {
        $config = '/etc/qpid/qpidd.conf'
      } else {
        $config = '/etc/qpidd.conf'
      }
    }

    default: {
      $config = '/etc/qpidd.conf'
    }
  }

  class {"qpid::server":
	  config_file => $config,
    auth => $enable_auth ? {
	    'y'  => 'yes',
	    default => 'no',
	    },
    clustered => false,
	    ssl_port      => '5671',
	    ssl           => false,
	    ssl_cert      => '',
	    ssl_key       => '',
	    ssl_database_password => '',
  }

  if $enable_ssl {
    enable_qpid_ssl {"qpid":}
  }
  if $enable_auth == 'y' {
    add_qpid_user {"qpid_user":}
  }

}

define enable_qpid_ssl {
  # User and group for the nss database
  group { 'qpidd':
    ensure => 'present',
  }

  exec { 'stop_qpid' :
    command => '/sbin/service qpidd stop',
    onlyif  => '/sbin/service qpidd status',
  }

  user { 'qpidd':
    ensure     => 'present',
    managehome => true,
    home       => '/var/run/qpidd',
    gid        => 'qpidd',
    before     => Class['qpid::server']
  }

  Exec['stop_qpid']->User['qpidd']

  file { 'pid_dir':
    path => '/var/run/qpidd',
    ensure => directory,
    owner => 'qpidd',
    group => 'qpidd',
    require => User['qpidd'],
  }

  file_line { 'pid_dir_conf':
    path => $qpid::server::config_file,
    line => 'pid-dir=/var/run/qpidd',
    require => File['pid_dir'],
  }
}

define add_qpid_user {
  qpid_user { 'guest':
    password  => 'guest',
    file  => '/var/lib/qpidd/qpidd.sasldb',
    realm  => 'AMQP',
    provider => 'saslpasswd2',
    require   => Class['qpid::server'],
  }

  file { 'sasldb_file':
    path => '/var/lib/qpidd/qpidd.sasldb',
    ensure => file,
    owner => 'qpidd',
    group => 'qpidd',
  }
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'amqp_172.16.7.15':
  host => '172.16.7.15',
  service_name => 'amqp',
  chain => 'INPUT',
  ports => ['5671', '5672'],
}

