Exec { timeout => 300 }

package{['nagios', 'nagios-plugins-nrpe', 'nagios-plugins-ping']:
    ensure => present,
    before => Class['nagios_configs']
}

class nagios_configs(){
    file{['/etc/nagios/nagios_command.cfg', '/etc/nagios/nagios_host.cfg']:
        ensure => 'present',
        mode => '0644',
        owner => 'nagios',
        group => 'nagios',
    }

    # Remove the entry for localhost, it contains services we're not
    # monitoring
    file{['/etc/nagios/objects/localhost.cfg']:
        ensure => 'present',
        content => '',
    }

    file_line{'nagios_host':
        path => '/etc/nagios/nagios.cfg',
        line => 'cfg_file=/etc/nagios/nagios_host.cfg',
    }

    file_line{'nagios_command':
        path => '/etc/nagios/nagios.cfg',
        line => 'cfg_file=/etc/nagios/nagios_command.cfg',
    }

    file_line{'nagios_service':
        path => '/etc/nagios/nagios.cfg',
        line => 'cfg_file=/etc/nagios/nagios_service.cfg',
    }

    nagios_command{'check_nrpe':
        command_line => '/usr/lib64/nagios/plugins/check_nrpe -H $HOSTADDRESS$ -c $ARG1$',
    }

    exec{'nagiospasswd':
        command => '/usr/bin/htpasswd -b /etc/nagios/passwd nagiosadmin redhat',
    }

    file {"/etc/nagios/keystonerc_admin":
        ensure  => "present", owner  => "nagios", mode => '0600',
        content => "export OS_USERNAME=admin
export OS_TENANT_NAME=admin
export OS_PASSWORD=redhat
export OS_AUTH_URL=http://172.16.7.15:35357/v2.0/ ",}

    nagios_host { '172.16.7.15': , use => 'linux-server', address => '172.16.7.15'}
file{"/usr/lib64/nagios/plugins/keystone-user-list":mode => 755, owner => "nagios", seltype => "nagios_unconfined_plugin_exec_t", content => template("packstack/keystone-user-list.erb"),}
nagios_command {"keystone-user-list": command_line => "/usr/lib64/nagios/plugins/keystone-user-list",}
file{"/usr/lib64/nagios/plugins/glance-index":mode => 755, owner => "nagios", seltype => "nagios_unconfined_plugin_exec_t", content => template("packstack/glance-index.erb"),}
nagios_command {"glance-index": command_line => "/usr/lib64/nagios/plugins/glance-index",}
file{"/usr/lib64/nagios/plugins/nova-list":mode => 755, owner => "nagios", seltype => "nagios_unconfined_plugin_exec_t", content => template("packstack/nova-list.erb"),}
nagios_command {"nova-list": command_line => "/usr/lib64/nagios/plugins/nova-list",}
file{"/usr/lib64/nagios/plugins/cinder-list":mode => 755, owner => "nagios", seltype => "nagios_unconfined_plugin_exec_t", content => template("packstack/cinder-list.erb"),}
nagios_command {"cinder-list": command_line => "/usr/lib64/nagios/plugins/cinder-list",}
file{"/usr/lib64/nagios/plugins/swift-list":mode => 755, owner => "nagios", seltype => "nagios_unconfined_plugin_exec_t", content => template("packstack/swift-list.erb"),}
nagios_command {"swift-list": command_line => "/usr/lib64/nagios/plugins/swift-list",}
file { '/etc/nagios/nagios_service.cfg': 
ensure => present, mode => 644,
owner => 'nagios', group => 'nagios',
before => Service['nagios'],
content => 'define service {
	check_command	check_nrpe!load5
	host_name	172.16.7.15
	name	load5-172.16.7.15
	normal_check_interval	5
	service_description	5 minute load average
	use	generic-service
	}
define service {
	check_command	check_nrpe!df_var
	host_name	172.16.7.15
	name	df_var-172.16.7.15
	service_description	Percent disk space used on /var
	use	generic-service
	}
define service {
	check_command	keystone-user-list
	host_name	172.16.7.15
	name	keystone-user-list
	normal_check_interval	5
	service_description	number of keystone users
	use	generic-service
	}
define service {
	check_command	glance-index
	host_name	172.16.7.15
	name	glance-index
	normal_check_interval	5
	service_description	number of glance images
	use	generic-service
	}
define service {
	check_command	nova-list
	host_name	172.16.7.15
	name	nova-list
	normal_check_interval	5
	service_description	number of nova vm instances
	use	generic-service
	}
define service {
	check_command	cinder-list
	host_name	172.16.7.15
	name	cinder-list
	normal_check_interval	5
	service_description	number of cinder volumes
	use	generic-service
	}
define service {
	check_command	swift-list
	host_name	172.16.7.15
	name	swift-list
	normal_check_interval	5
	service_description	number of swift containers
	use	generic-service
	}
'}
}

class{'nagios_configs':
    notify => [Service['nagios'], Service['httpd']],
}

include concat::setup

class {'apache':
    purge_configs => false,
}
class {'apache::mod::php': }

service{['nagios']:
    ensure => running,
    enable => true,
    hasstatus => true,
}

firewall { '001 nagios incoming':
    proto    => 'tcp',
    dport    => ['80'],
    action   => 'accept',
}
