Exec { timeout => 300 }


class {"nova::cert":
    enabled => true,
}


class {"nova::conductor":
    enabled => true,
}

package{'python-cinderclient':
    before => Class["nova"]
}

nova_config{
    "DEFAULT/volume_api_class": value => "nova.volume.cinder.API";
}

class {"nova::compute":
    enabled => true,
    vncproxy_host => "172.16.7.15",
    vncserver_proxyclient_address => "172.16.7.15",
}


# Note : remove this once we're installing a version of openstack that isn't
#        supported on RHEL 6.3
if $::is_virtual_packstack == "true" and $::osfamily == "RedHat" and
    $::operatingsystemrelease == "6.3"{
    file { "/usr/bin/qemu-system-x86_64":
        ensure => link,
        target => "/usr/libexec/qemu-kvm",
        notify => Service["nova-compute"],
    }
}

# Tune the host with a virtual hosts profile
package {'tuned':
    ensure => present,
}

service {'tuned':
    ensure => running,
    require => Package['tuned'],
}

if $::operatingsystem == 'Fedora' and $::operatingsystemrelease == 19 {
    # older tuned service is sometimes stucked on Fedora 19
    exec {'tuned-update':
       path => ['/sbin', '/usr/sbin', '/bin', '/usr/bin'],
       command => 'yum update -y tuned',
       logoutput => 'on_failure',
    }

    exec {'tuned-restart':
       path => ['/sbin', '/usr/sbin', '/bin', '/usr/bin'],
       command => 'systemctl restart tuned.service',
       logoutput => 'on_failure',
    }

    Service['tuned'] -> Exec['tuned-update'] -> Exec['tuned-restart'] -> Exec['tuned-virtual-host']
}

exec {'tuned-virtual-host':
    unless => '/usr/sbin/tuned-adm active | /bin/grep virtual-host',
    command => '/usr/sbin/tuned-adm profile virtual-host',
    require => Service['tuned'],
}
Firewall <| |> -> Class['nova::compute::libvirt']

# Ensure Firewall changes happen before libvirt service start
# preventing a clash with rules being set by libvirt

if $::is_virtual_packstack == "true" {
    $libvirt_type = "qemu"
    nova_config{
        "DEFAULT/libvirt_cpu_mode": value => "none";
    }
}else{
    $libvirt_type = "kvm"
}

nova_config{
  "DEFAULT/libvirt_inject_partition": value => "-1";
}

exec { 'qemu-kvm':
    path => '/usr/bin',
    command => 'yum install -y qemu-kvm',
    before => Class['nova::compute::libvirt']
}

class { 'nova::compute::libvirt':
  libvirt_type                => "$libvirt_type",
  vncserver_listen            => "172.16.7.15",
}

exec {'load_kvm':
    user => 'root',
    command => '/bin/sh /etc/sysconfig/modules/kvm.modules',
    onlyif => '/usr/bin/test -e /etc/sysconfig/modules/kvm.modules',
}

Class['nova::compute']-> Exec["load_kvm"]

file_line { 'libvirt-guests':
    path  => '/etc/sysconfig/libvirt-guests',
    line  => 'ON_BOOT=ignore',
    match => '^[\s#]*ON_BOOT=.*',
    require => Class['nova::compute::libvirt']
}

# Remove libvirt's default network (usually virbr0) as it's unnecessary and can be confusing
exec {'virsh-net-destroy-default':
    onlyif  => '/usr/bin/virsh net-list | grep default',
    command => '/usr/bin/virsh net-destroy default',
    require => Package['libvirt'],
}

exec {'virsh-net-undefine-default':
    onlyif  => '/usr/bin/virsh net-list --inactive | grep default',
    command => '/usr/bin/virsh net-undefine default',
    require => Exec['virsh-net-destroy-default'],
}

class { 'ceilometer':
    metering_secret => 'd52b59d6c0e34231',
    qpid_hostname   => '172.16.7.15',
    qpid_username  => 'guest',
    qpid_password  => 'guest',
    rpc_backend     => 'ceilometer.openstack.common.rpc.impl_qpid',
    verbose         => true,
    debug           => false
}

# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'nova_compute':
  host => '172.16.7.15',
  service_name => 'nova compute',
  chain => 'INPUT',
  ports => ['5900-5999'],
}



nova_config{
    # OpenStack doesn't include the CoreFilter (= CPU Filter) by default
    "DEFAULT/scheduler_default_filters":
        value => "RetryFilter,AvailabilityZoneFilter,RamFilter,ComputeFilter,ComputeCapabilitiesFilter,ImagePropertiesFilter,CoreFilter";
    "DEFAULT/cpu_allocation_ratio":
        value => "16.0";
    "DEFAULT/ram_allocation_ratio":
        value => "1.5";
}

class {"nova::scheduler":
    enabled => true,
}

class {"nova::vncproxy":
    enabled => true,
}

class {"nova::consoleauth":
    enabled => true,
}

firewall { '001 novncproxy incoming':
    proto    => 'tcp',
    dport    => ['6080'],
    action   => 'accept',
}



class { "nova":
    glance_api_servers => "172.16.7.15:9292",
    qpid_hostname      => "172.16.7.15",
    qpid_username      => 'guest',
    qpid_password      => 'guest',
    rpc_backend        => 'nova.openstack.common.rpc.impl_qpid',
    qpid_port          => '5672',
    qpid_protocol      => 'tcp',
    verbose            => true,
    debug              => false,
}

# Ensure Firewall changes happen before nova services start
# preventing a clash with rules being set by nova-compute and nova-network
Firewall <| |> -> Class['nova']

nova_config{
    "DEFAULT/sql_connection": value => "mysql://nova:redhat@172.16.7.15/nova";
    "DEFAULT/metadata_host": value => "172.16.7.15";
}




class {"nova::network::neutron":
  neutron_admin_password => "redhat",
  neutron_auth_strategy => "keystone",
  neutron_url => "http://172.16.7.15:9696",
  neutron_admin_tenant_name => "services",
  neutron_admin_auth_url => "http://172.16.7.15:35357/v2.0",
}

class {"nova::compute::neutron":
  libvirt_vif_driver => "nova.virt.libvirt.vif.LibvirtGenericVIFDriver",
}
