Exec { timeout => 300 }


package { 'curl': ensure => present }

class { 'memcached':
}

class { 'swift::proxy':
  proxy_local_net_ip => '172.16.7.15',
  pipeline           => [
    #'catch_errors',
    'healthcheck',
    'cache',
    #'ratelimit',
    'authtoken',
    'keystone',
    'staticweb',
    'tempurl',
    #'account_quotas',
    #'container_quotas',
    'proxy-server'
  ],
  account_autocreate => true,
}

# configure all of the middlewares
class { [
    'swift::proxy::catch_errors',
    'swift::proxy::healthcheck',
    'swift::proxy::cache',
    'swift::proxy::staticweb',
    'swift::proxy::tempurl',
    'swift::proxy::account_quotas',
    'swift::proxy::container_quotas'
]: }

class { 'swift::proxy::ratelimit':
    clock_accuracy         => 1000,
    max_sleep_time_seconds => 60,
    log_sleep_time_seconds => 0,
    rate_buffer_seconds    => 5,
    account_ratelimit      => 0
}

class { 'swift::proxy::keystone':
    operator_roles => ['admin', 'SwiftOperator'],
}

class { 'swift::proxy::authtoken':
    admin_user        => 'swift',
    admin_tenant_name => 'services',
    admin_password    => 'redhat',
    # assume that the controller host is the swift api server
    auth_host         => '172.16.7.15',
}

firewall { '001 swift proxy incoming':
    proto    => 'tcp',
    dport    => ['8080'],
    action   => 'accept',
}


# install all swift storage servers together
class { 'swift::storage::all':
  storage_local_net_ip => '172.16.7.15',
  allow_versions => true,
  require => Class['swift'],
}

if(!defined(File['/srv/node'])) {
  file { '/srv/node':
    owner  => 'swift',
    group  => 'swift',
    ensure => directory,
    require => Package['openstack-swift'],
  }
}

swift::ringsync{["account","container","object"]:
    ring_server => '172.16.7.15',
    before => Class['swift::storage::all'],
    require => Class['swift'],
}





swift::storage::loopback { ['device1']:
  base_dir     => '/srv/loopback-device',
  mnt_base_dir => '/srv/node',
  require      => Class['swift'],
  fstype       => 'ext4',
  seek         => '2097152',
}



# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'swift_storage_and_rsync_172.16.7.15':
  host => '172.16.7.15',
  service_name => 'swift storage and rsync',
  chain => 'INPUT',
  ports => ['6000', '6001', '6002', '873'],
}



class { 'ssh::server::install': }

Class['swift'] -> Service <| |>
class { 'swift':
    # not sure how I want to deal with this shared secret
    swift_hash_suffix => 'c64663775a9f418e',
    package_ensure    => latest,
}
